import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { csv, arc, nest, pie } from 'd3';

const width = 960;
const height = 520;
const centerX = width / 2;
const centerY = height / 2;
const csvUrl =
  'https://gist.githubusercontent.com/jgorsett/6492ab1253c04167d1639c4ced71b3bf/raw/60ac51d04ee9806242f51689466c6197af59301d/hotaling_cocktails%2520-%2520Cocktails%2520-%2520Parsed%2520Ingredients.csv';
const App = () => {
  const [data, setData] = useState(null);

  useEffect(() => {
    csv(csvUrl).then(setData);
  }, []);

  
  if (!data) {
    return <pre>Loading...</pre>;
  }

  
  
  let filteredData =  nest()
    .key(function(d) { return d.Ingredient; })
    .rollup(function(ingredients) { return ingredients.length; })
    .entries(data)

  filteredData.forEach(function(d) {
 		d.Ingredient = d.key;
 		d.IngredientCount = d.value});
    
  filteredData = filteredData
    	  	.sort(function(x, y){return d3.descending(x.IngredientCount, y.IngredientCount)})
					.slice(0,10);
  
const arcs = pie()
    .value(function(d) { return d.IngredientCount; })
    (filteredData);
  
const color = d3.schemeCategory10;
                                  
console.log(color)
console.log(filteredData[0]);

  const tooltipIngredient = d => d['data']['key'];
  const tooltipCount = d => d['data']['value'];
  
  return (
    <svg width={width} height={height}>
      <g transform={`translate(${centerX}, ${centerY})`}>
			
        {arcs.map((d, i) => (
          <g>
          <path
            fill={color[i]}
            stroke="White"
            stroke-width="5"
            d={arc()({
              startAngle: d.startAngle,
              endAngle: d.endAngle,
              innerRadius: 100,
              outerRadius: 200,
            })}
          />
          <title className="tooltip">{tooltipIngredient(d) + " (" + tooltipCount(d) +  ")"}</title>
          </g>
        ))
        };
      </g>
    </svg>
  );
};

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);













